@@ -1,9 +1,9 @@
 package UUID::Random::Secure;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-01-18'; # DATE
+our $DATE = '2021-01-20'; # DATE
 our $DIST = 'UUID-Random-Secure'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use strict;
 use warnings;
@@ -14,10 +14,20 @@ sub generate {
         "%08x-%04x-%04x-%04x-%04x%08x",
         irand(),
         irand(2**16),
-        irand(2**16),
-        irand(2**16),
-        irand(2**16),
+        irand(2**16) ,
+        irand(2**16) ,
+        irand(2**16), irand(),
+    );
+}
+
+sub generate_rfc {
+    sprintf(
+        "%08x-%04x-%04x-%04x-%04x%08x",
         irand(),
+        irand(2**16),
+        irand(2**16) & 0x00ff | 0x4000,
+        irand(2**16) & 0xbfff | 0x8000,
+        irand(2**16), irand(),
     );
 }
 
@@ -36,7 +46,7 @@ UUID::Random::Secure - Like UUID::Random, but uses Math::Random::Secure for rand
 
 =head1 VERSION
 
-This document describes version 0.002 of UUID::Random::Secure (from Perl distribution UUID-Random-Secure), released on 2021-01-18.
+This document describes version 0.003 of UUID::Random::Secure (from Perl distribution UUID-Random-Secure), released on 2021-01-20.
 
 =head1 SYNOPSIS
 
@@ -47,13 +57,27 @@ Use like you would L<UUID::Random>:
 
 =head1 DESCRIPTION
 
-Note that this module currently does not produce RFC 4122-compliant v4 (random)
-UUIDs (no encoding of variant and version information into the UUID).
-
 =head1 FUNCTIONS
 
 =head2 generate
 
+Generate a single v4 UUID string in the formatted 32 hexadecimal digits:
+
+ xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx
+
+Note that this module does not produce RFC 4122-compliant v4 (random) UUIDs (no
+encoding of variant and version information into the UUID). See L</generate_rfc>
+for UUIDs that comply to RFC 4122.
+
+=head2 generate_rfc
+
+Generate RFC-compliant a single v4 UUID string in the form of:
+
+ xxxxxxxx-xxxx-Mxxx-Nxxx-xxxxxxxxxxxx
+
+where C<x> is any hexadecimal digits ([0-9a-f]), C<M> is C<4>, and N is either
+C<8>, C<9>, C<a>, or C<b> (1000, 1001, 1010, or 1011 in binary).
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/UUID-Random-Secure>.
